@@ -1,5 +1,8 @@
 import os
 
+import click
+import winrm
+
 from agileupstate.state import State
 from agileupstate.terminal import print_cross_message, print_check_message
 
@@ -28,12 +31,10 @@ def reset_windows(state: State):
 def windows_bottom(state: State, username, password):
     with open(INVENTORY, 'a') as f:
         f.write('[' + f'{state.state_name_underscore}:vars' + ']\n')
-        f.write('[' + f'ansible_user={username}' + ']\n')
-        f.write('[' + f'ansible_password={password}' + ']\n')
-        f.write('[' + 'ansible_connection=winrm' + ']\n')
-        f.write('[' + 'ansible_port=5986' + ']\n')
-        f.write('[' + 'ansible_winrm_server_cert_validation=ignore' + ']\n')
-        f.write('[' + 'ansible_winrm_server_cert_validation=ignore' + ']\n')
+        f.write(f'ansible_user={username}' + '\n')
+        f.write(f'ansible_password={password}' + '\n')
+        f.write('ansible_connection=winrm' + '\n')
+        f.write('ansible_port=5986' + '\n')
 
 
 def create_inventory(state: State, tfstate_content):
@@ -45,6 +46,7 @@ def create_inventory(state: State, tfstate_content):
         key = tfstate_content['outputs']['vm-rsa-private-key']['value']
         print_check_message(f'Creating Linux inventory for {ips}')
         os.umask(0)
+        click.secho(f'- Writing {PRIVATE_KEY_PEM}', fg='blue')
         with open(PRIVATE_KEY_PEM, 'w', opener=opener) as f:
             f.write(key)
 
@@ -52,7 +54,7 @@ def create_inventory(state: State, tfstate_content):
         for ip in ips:
             with open(INVENTORY, 'a') as f:
                 f.write(ip + f' ansible_ssh_private_key_file={PRIVATE_KEY_PEM}\n')
-        print_check_message(f'Written inventory file {INVENTORY}')
+        click.secho(f'- Writing inventory file {INVENTORY}', fg='blue')
 
     except KeyError:
         print_check_message(f'Creating Windows inventory for {ips}')
@@ -63,3 +65,14 @@ def create_inventory(state: State, tfstate_content):
             with open(INVENTORY, 'a') as f:
                 f.write(ip + '\n')
         windows_bottom(state, admin_username, admin_password)
+        click.secho(f'- Writing inventory file {INVENTORY}', fg='blue')
+
+
+def ping_windows(auth):
+    session = winrm.Session('https://ags-w-arm1.meltingturret.io:5986',
+                            ca_trust_path='chain.meltingturret.io.pem',
+                            cert_pem='azureuser@meltingturret.io.pem',
+                            cert_key_pem='azureuser@meltingturret.io.key',
+                            transport='certificate', auth=auth)
+    response = session.run_cmd('ipconfig', ['/all'])
+    print(response.std_out)
