@@ -1,9 +1,12 @@
+from zipfile import ZipFile
+
 import click
 
-from agileupstate.ansible import create_inventory
+from agileupstate.ansible import create_inventory, ping_windows
 from agileupstate.client import get_version_string
 from agileupstate.terminal import print_check_message, print_cross_message
-from agileupstate.vault import address, is_ready, create_state, load_state, create_tfstate, load_tfstate
+from agileupstate.vault import address, is_ready, create_state, load_state, create_tfstate, load_tfstate, \
+    load_vault_file
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
@@ -33,9 +36,9 @@ def create() -> None:
     create_state()
 
 
-@cli.command(help='Save client states to vault.')
+@cli.command(help='Save client tfstates to vault.')
 def save() -> None:
-    click.secho('- Save client states to vault', fg='green')
+    click.secho('- Save client tfstates to vault', fg='green')
     state = load_state()
     tfstate_content = state.read_tfstate()
     create_tfstate(state, tfstate_content)
@@ -57,5 +60,25 @@ def inventory() -> None:
     create_inventory(state, tfstate_content)
 
 
+@cli.command(help='Generate cloud init zip file for mTLS data.')
+@click.option('--pfx-path', required=True, help='Vault path to windows WinRM server pfx file.')
+@click.option('--pubkey-path', required=True, help='Vault path to windows client public key file.')
+def cloud_init(pfx_path, pubkey_path) -> None:
+    filename1 = load_vault_file(pfx_path)
+    filename2 = load_vault_file(pubkey_path)
+    with ZipFile('cloud-init.zip', 'w') as z:
+        z.write(filename1)
+        z.write(filename2)
+    click.secho('- Writing cloud-init.zip', fg='blue')
+
+
+@cli.command(help='Check connection.')
+@click.option('--username', help='Username for windows access.')
+@click.option('--password', help='Password for windows access.')
+def ping(username, password) -> None:
+    click.secho(f'- Checking Windows WinRM connection for user {username}', fg='green')
+    ping_windows((username, password))
+
+
 if __name__ == '__main__':
     exit(cli())
